@@ -9,11 +9,14 @@
 #' @param dividend_yield - dividend yield
 #' @param volatility - volatility of the underlying asset
 #' @param model - the model to be chosen
-#' @param option_type in c("European", "American", "Asian", "Digital") - the
+#' @param option_type in c("European", "American", "Asian", "Digital",
+#' "Binomial) - the
 #' type of option to be considered
-#' @param payoff - in c("call", "put")
-#' @param greek - greeks to be calculated in c("fair_value", "delta", "vega",
-#' "theta", "rho", "epsilon", "lambda", "gamma", "vanna")
+#' @param payoff - in c("call", "put", "cash_or_nothing_call",
+#' "cash_or_nothing_put", "asset_or_nothing_call", "asset_or_nothing_put")
+#' @param greek - Greeks to be calculated in c("fair_value", "delta", "vega",
+#' "theta", "rho", "epsilon", "lambda", "gamma", "vanna", "charm", "vomma",
+#' "veta", "vera", "speed", "zomma", "color", "ultima")
 #'
 #' @return Named vector containing the values of the Greeks specified in the
 #' parameter \code{greek}.
@@ -76,21 +79,22 @@ Greeks <-
     }
 
     else if (tolower(option_type) == "digital" && tolower(model) == "black_scholes") {
-      if (tolower(payoff) == "call") {
-        payoff <- "digital_call"
-      } else if (tolower(payoff) == "put") {
-        payoff <- "digital_put"
-      } else {
-        stop("Wrong input or not yet implemented.")
+      if (tolower(payoff) %in% c("call", "put")) {
+        stop("Please choose one of the following:
+                'cash_or_nothing_call',
+                'cash_or_nothing_put',
+                'asset_or_nothing_call',
+                'asset_or_nothing_put'.")
+        return()
       }
-      return(Malliavin_European_Greeks(payoff = payoff,
-                                       greek = greek,
-                                       initial_price = initial_price,
-                                       exercise_price = exercise_price,
-                                       r = r,
-                                       time_to_maturity = time_to_maturity,
-                                       volatility = volatility,
-                                       dividend_yield = dividend_yield))
+      return(BS_European_Greeks(payoff = payoff,
+                                greek = greek,
+                                initial_price = initial_price,
+                                exercise_price = exercise_price,
+                                r = r,
+                                time_to_maturity = time_to_maturity,
+                                volatility = volatility,
+                                dividend_yield = dividend_yield))
     }
 
     else {
